<?php

namespace Drupal\ro_dashboard\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\ro_dashboard\Service\SiteInfoUpdateService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Create demo entities.
 */
class UpdateSiteController extends ControllerBase implements ContainerInjectionInterface {


  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The service to collect the data.
   *
   * @var \Drupal\ro_dashboard\Service\SiteInfoUpdateService
   */
  protected $siteInfoUpdateService;

  /**
   * Constructs a new UpdateSiteController object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\ro_dashboard\Service\SiteInfoUpdateService $site_info_update_service
   *   The service to collect the data.
   */
  final public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
    SiteInfoUpdateService $site_info_update_service,
  ) {
    $this->entityTypeManager = $entity_type_manager;
    $this->siteInfoUpdateService = $site_info_update_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('ro_dashboard.site_info_update')
    );
  }

  /**
   * Collects information about a site and updates the site.
   *
   * @param string $ro_dashboard_site
   *   The site to update.
   *
   *   Return [].
   */
  public function updateSite(string $ro_dashboard_site) {
    /** @var \Drupal\ro_dashboard\Entity\RoDashboardSite $site_to_update */
    $site_to_update = $this->entityTypeManager()->getStorage('ro_dashboard_site')->load($ro_dashboard_site);
    $updated = $this->siteInfoUpdateService->updateSite($site_to_update);

    if ($updated) {
      $this->messenger()->addMessage($this->t('Site @site_name is updated.', ['@site_name' => $site_to_update->label()]));
    }
    else {
      $this->messenger()->addMessage($this->t('Site @site_name could not be updated, or there was nothing to process.', ['@site_name' => $site_to_update->label()]));
    }
    return $this->redirect('view.ro_sites.page_1');
  }

  /**
   * Checks access for a specific request.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   * @param int $ro_dashboard_site
   *   The node id.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(AccountInterface $account, $ro_dashboard_site) {
    return AccessResult::allowedIfHasPermission($account, 'update ro_dashboard sites');
  }

}
