<?php

namespace Drupal\ro_dashboard\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\Core\Entity\EntityPublishedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Represents a Multi Site Status Dashboard Site.
 */
interface RoDashboardSiteInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface, EntityPublishedInterface {

  /**
   * Site is not published.
   */
  public const NOT_PUBLISHED = 'Not published';

  /**
   * Site is published.
   */
  public const PUBLISHED = 'Published';

  /**
   * Gets the Multi Site Status Site creation timestamp.
   *
   * @return int|null
   *   The created time.
   */
  public function getCreatedTime(): ?int;

  /**
   * Sets the Multi Site Status Dashboard Site creation timestamp.
   *
   * @param int $timestamp
   *   The created time.
   *
   * @return \Drupal\ro_dashboard\Entity\RoDashboardSite
   *   The Multi Site Status Dashboard Site.
   */
  public function setCreatedTime($timestamp): RoDashboardSite;

  /**
   * Gets the Multi Site Status Dashboard Site modification timestamp.
   *
   * @return int|null
   *   The modified time.
   */
  public function getChangedTime(): ?int;

  /**
   * Sets the Multi Site Status Dashboard Site data.
   *
   * @param array $report
   *   An array with form values.
   *
   * @return \Drupal\ro_dashboard\Entity\RoDashboardSite
   *   The Multi Site Status Dashboard Site.
   */
  public function setReport(array $report): RoDashboardSite;

  /**
   * Gets the Multi Site Status Dashboard Site data.
   *
   * @return array
   *   An array with all site data.
   */
  public function getReport(): array;

  /**
   * Get the site URL.
   *
   * @return string
   *   The site URL.
   */
  public function getSiteUrl(): string;

  /**
   * Get the items to ignore in the SiteGuardian status report.
   *
   * @return array
   *   The items to ignore.
   */
  public function getSgStatusReportIgnore(): array;

  /**
   * Get the modules to ignore in the SiteGuardian updates report.
   *
   * @return array
   *   The modules to ignore.
   */
  public function getSgModuleUpdateReportIgnore(): array;

}
