<?php

namespace Drupal\ro_dashboard\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Form controller for the Multi Site Status Dashboard Sites.
 *
 * @ingroup ro_dashboard
 */
class RoDashboardSiteForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $items_to_move = [
      'sg_token',
      'sg_status_report',
      'sg_status_report_ignore',
      'sg_module_update_report',
      'sg_module_update_report_ignore',
    ];
    $form['site_guardian'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Site Guardian global settings'),
    ];
    $form['site_guardian']['sg_description'] = [
      '#markup' => $this->t('<a href="@sg_url">Site Guardian</a> is a
      Module that helps you collect status information about your site.
      It can also show if there are updates available for modules in your site.
      The settings below are <strong>site-specific</strong> settings that apply
      only to this site. These will be merged with the
      <a href="@sg_settings">general settings</a>.', [
        '@sg_url' => 'https://www.drupal.org/project/site_guardian',
        '@sg_settings' => Url::fromRoute('ro_dashboard.settings')->toString(),
      ]),
    ];
    foreach ($items_to_move as $item) {
      $form['site_guardian'][$item] = $form[$item];
      unset($form[$item]);
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $entity = $this->entity;
    // Set new Revision.
    $entity->setNewRevision();
    $form_state->setRedirectUrl(Url::fromRoute('view.ro_sites.page_1'));
    return parent::save($form, $form_state);
  }

}
