<?php

namespace Drupal\ro_dashboard\Plugin\QueueWorker;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\ro_dashboard\Service\SiteInfoUpdateService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the site update queue worker.
 *
 * @QueueWorker (
 *   id = "ro_dashboard_update_sites_job",
 *   title = @Translation("Update Site job"),
 *   cron = {"time" = 60}
 * )
 */
class UpdateSitesJob extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * The service to collect the data.
   *
   * @var \Drupal\ro_dashboard\Service\SiteInfoUpdateService
   */
  protected $siteInfoUpdateService;

  /**
   * Constructor for the UpdateSitesJob.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager interface.
   * @param \Drupal\ro_dashboard\Service\SiteInfoUpdateService $site_info_update_service
   *   The service to collect the data.
   */
  public function __construct(
    array $configuration,
    string $plugin_id,
    $plugin_definition,
    EntityTypeManagerInterface $entity_type_manager,
    SiteInfoUpdateService $site_info_update_service,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->entityTypeManager = $entity_type_manager;
    $this->siteInfoUpdateService = $site_info_update_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('ro_dashboard.site_info_update')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    $site_id = $data['site_id'];
    $site_to_update = $this->entityTypeManager
      ->getStorage('ro_dashboard_site')->load($site_id);
    $processed = $this->siteInfoUpdateService->updateSite($site_to_update);
    if (!$processed) {
      throw new \Exception('Site #' . $site_id . ' was not processed correctly.');
    }
  }

}
