<?php

namespace Drupal\ro_dashboard;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Access controller for Multi Site Status Dashboard Sites.
 */
class RoDashboardSiteAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermission($account, 'view monitored sites');

      case 'update':
      case 'view all revisions':
      case 'view revision':
      case 'delete revision':
        return AccessResult::allowedIfHasPermission($account, 'edit monitored sites');

      case 'revert':
        return AccessResult::allowedIfHasPermission($account, 'edit monitored sites')
          ->andIf(AccessResult::forbiddenIf($entity->isDefaultRevision() && $entity->isLatestRevision()));

      case 'delete':
        return AccessResult::allowedIfHasPermission($account, 'delete monitored sites');
    }
    return AccessResult::neutral();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add monitored sites');
  }

}
