<?php

namespace Drupal\ro_dashboard\Tests\Kernel;

use Drupal\Core\Database\Database;
use Drupal\Core\Queue\DatabaseQueue;
use Drupal\KernelTests\KernelTestBase;
use Drupal\ro_dashboard\Entity\RoDashboardSite;

/**
 * Test queue functionality.
 */
class QueueTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'user',
    'system',
    'filter',
    'field',
    'text',
    'link',
    'datetime',
    'ro_dashboard',
    'options',
    'file',
  ];

  /**
   * {@inheritdoc}
   */
  public function setUp():void {
    parent::setUp();
    $this->installEntitySchema('node');
    $this->installEntitySchema('ro_dashboard_site');
    $this->installEntitySchema('user');
    $this->installConfig(['system']);
  }

  /**
   * Tests adding all sites to queue.
   */
  public function testAddSiteToQueue() {
    $ro_dashboard_site = RoDashboardSite::create([
      'id' => '7',
      'label' => 'Test site',
      'status' => '1',
      'created' => time(),
      'changed' => time(),
      'site_url' => 'https://testsite.com',
      'sg_token' => 'test_token',
      'sg_status_report' => TRUE,
      'sg_status_report_ignore' => '',
      'sg_module_update_report' => TRUE,
      'sg_module_update_report_ignore' => '',
    ]);
    $ro_dashboard_site->save();
    $ro_dashboard_site = RoDashboardSite::create([
      'id' => '8',
      'label' => 'Test site 2',
      'status' => '1',
      'created' => time(),
      'changed' => time(),
      'site_url' => 'https://testsite2.com',
      'sg_token' => 'test_token2',
      'sg_status_report' => TRUE,
      'sg_status_report_ignore' => '',
      'sg_module_update_report' => TRUE,
      'sg_module_update_report_ignore' => '',
    ]);
    $ro_dashboard_site->save();

    $queue = new DatabaseQueue('ro_dashboard_update_sites_job', Database::getConnection());
    $queue->createQueue();
    \Drupal::service('ro_dashboard.site_info_update')->scheduleSiteUpdate();
    $number_of_items_in_queue = $queue->numberOfItems();
    $this->assertEquals('2', $number_of_items_in_queue, 'There should be 2 items in the queue.');
    $item_data = $queue->claimItem()->data;
    $this->assertEquals('7', $item_data['site_id'], 'The site ID should be 7.');
    $queue->deleteQueue();
  }

}
